﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinMaskedEdit;

namespace WNE_ClickDisabledCheckbox
{
    class CustomCreationFilter : IUIElementCreationFilter
    {
        private CheckBoxUIElement checkUIElement;
        private CheckState currentState = CheckState.Unchecked;

        public event EventHandler<UIElementEventArgs> CheckBoxClicked;

        public CheckState CurrentState
        {
            get { return currentState; }
            set { currentState = value; }
        }

        public void AfterCreateChildElements(UIElement parent)
        {
            if (parent is EditorWithMaskEmbeddableUIElement)
            {
                var editPortion = parent.GetDescendant(typeof(MaskedEditUIElement));

                checkUIElement = editPortion.GetDescendant(typeof(CheckBoxUIElement)) as CheckBoxUIElement;

                if (checkUIElement == null)
                {
                    checkUIElement = new CheckBoxUIElement(parent);
                    checkUIElement.ElementClick +=checkUIElement_ElementClick;
                }

                // Set the checkbox to have the same height and width as the editor,
                // with one pixel for the borders.
                checkUIElement.Rect = new Rectangle(parent.Rect.X + 1, parent.Rect.Y +1 , parent.Rect.Height -2,
                    parent.Rect.Height -2);

                checkUIElement.CheckAlign = ContentAlignment.MiddleCenter;
                checkUIElement.CheckState = currentState;

                // Resize the editor so there is enough space for the checkbox
                editPortion.Rect = new Rectangle(editPortion.Rect.X + editPortion.Rect.Height - 2, editPortion.Rect.Y, 
                    editPortion.Rect.Width - editPortion.Rect.Height + 2, editPortion.Rect.Height);
                parent.ChildElements.Add(checkUIElement);
            }
        }

        void checkUIElement_ElementClick(object sender, UIElementEventArgs e)
        {
            if (CheckBoxClicked != null)
                CheckBoxClicked.Invoke(sender, e);
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}
